@@ -19,6 +19,14 @@ class ShopifyThrottledError(ShopifyError):
     pass
 
 
+class ShopifyExceedingMaxCostError(ShopifyError):
+    """
+    Exception to identify errors that are due to queries exceeding the max query size
+    """
+
+    pass
+
+
 def not_our_fault(exception: Exception):
     """Simple function to identify invalid Shopify calls, i.e. our mistake.
 
